@@ -30,6 +30,7 @@ __all__ = (
     "JobErrorTypeDef",
     "ExportAssetToSignedUrlResponseDetailsTypeDef",
     "AssetDestinationEntryTypeDef",
+    "ExportServerSideEncryptionTypeDef",
     "ExportAssetsToS3ResponseDetailsTypeDef",
     "ImportAssetFromSignedUrlResponseDetailsTypeDef",
     "ImportAssetsFromS3ResponseDetailsTypeDef",
@@ -161,10 +162,26 @@ class AssetDestinationEntryTypeDef(
     pass
 
 
-ExportAssetsToS3ResponseDetailsTypeDef = TypedDict(
-    "ExportAssetsToS3ResponseDetailsTypeDef",
+ExportServerSideEncryptionTypeDef = TypedDict(
+    "ExportServerSideEncryptionTypeDef", {"KmsKeyArn": str, "Type": Literal["aws:kms", "AES256"]}
+)
+
+_RequiredExportAssetsToS3ResponseDetailsTypeDef = TypedDict(
+    "_RequiredExportAssetsToS3ResponseDetailsTypeDef",
     {"AssetDestinations": List[AssetDestinationEntryTypeDef], "DataSetId": str, "RevisionId": str},
 )
+_OptionalExportAssetsToS3ResponseDetailsTypeDef = TypedDict(
+    "_OptionalExportAssetsToS3ResponseDetailsTypeDef",
+    {"Encryption": ExportServerSideEncryptionTypeDef},
+    total=False,
+)
+
+
+class ExportAssetsToS3ResponseDetailsTypeDef(
+    _RequiredExportAssetsToS3ResponseDetailsTypeDef, _OptionalExportAssetsToS3ResponseDetailsTypeDef
+):
+    pass
+
 
 _RequiredImportAssetFromSignedUrlResponseDetailsTypeDef = TypedDict(
     "_RequiredImportAssetFromSignedUrlResponseDetailsTypeDef",
@@ -434,10 +451,22 @@ ExportAssetToSignedUrlRequestDetailsTypeDef = TypedDict(
     {"AssetId": str, "DataSetId": str, "RevisionId": str},
 )
 
-ExportAssetsToS3RequestDetailsTypeDef = TypedDict(
-    "ExportAssetsToS3RequestDetailsTypeDef",
+_RequiredExportAssetsToS3RequestDetailsTypeDef = TypedDict(
+    "_RequiredExportAssetsToS3RequestDetailsTypeDef",
     {"AssetDestinations": List[AssetDestinationEntryTypeDef], "DataSetId": str, "RevisionId": str},
 )
+_OptionalExportAssetsToS3RequestDetailsTypeDef = TypedDict(
+    "_OptionalExportAssetsToS3RequestDetailsTypeDef",
+    {"Encryption": ExportServerSideEncryptionTypeDef},
+    total=False,
+)
+
+
+class ExportAssetsToS3RequestDetailsTypeDef(
+    _RequiredExportAssetsToS3RequestDetailsTypeDef, _OptionalExportAssetsToS3RequestDetailsTypeDef
+):
+    pass
+
 
 ImportAssetFromSignedUrlRequestDetailsTypeDef = TypedDict(
     "ImportAssetFromSignedUrlRequestDetailsTypeDef",
